==> react-native-hotqa-sdk-0.2.4.tgz: package/src/router/index.js <==
import 'react-native-gesture-handler';

import * as React from 'react';
import {NavigationContainer} from '@react-navigation/native';
import {createStackNavigator} from '@react-navigation/stack';
import Icon from 'react-native-vector-icons/FontAwesome';
import Feather from 'react-native-vector-icons/Feather';

//screen
import HomeScreen from '../pages/home';
import StartScreen from '../pages/start';
import CongratulationsScreen from '../components/Congratulations';
import CodeTest from '../components/CodeTest';
import QuestionIntro from '../components/swiper/intro-question';

Icon.loadFont();
Feather.loadFont();
const Stack = createStackNavigator();

const token_fake =
  'EKID eyJhbGciOiJIUzI1NiJ9.eyJzdWIiOiIxNTc4MSIsImlhdCI6MTYyMDY0MTU5MSwiZXhwIjoxNjI0MjQxNTkxLCJkZXZpY2VfaWQiOiJhYTZkMzEyNC1lM2I1LTRhMmUtYjUxOC1mMTQwNzNkNzBhZDgiLCJ0eXBlIjoiU1RVREVOVCJ9.B4VXT3a5IXVi2Qeg_4yKxSBAVCSZkVmBCAg6j2NEWZc';

const fixLinkTest =
  // 'https://test-dev.ekidpro.com/main/test/joined/36766/take?code=47500719-6';
  'https://test-dev.ekidpro.com/main/test/free/772/take?code=IO3JZODR33'; //772

const params = {
  nav: 'navigation',
  domain: 'https://api-dev.ekidpro.com',
  linkUrl: fixLinkTest,
  token: token_fake,
  student_id: 15781,
  lesson_id: 'lessonId',
  isFinish: false,
  isResult: false,
};

const Router = (props) => {
  return (
    <NavigationContainer independent={true}>
      <Stack.Navigator initialRouteName="Home">
        <Stack.Screen
          name="Home"
          component={HomeScreen}
          options={{headerShown: false}}
          initialParams={props?.params}
          // initialParams={params}
        />
        <Stack.Screen
          name="Start"
          component={StartScreen}
          options={{headerShown: false}}
          initialParams={props?.params}
        />
        <Stack.Screen
          name="Congratulations"
          component={CongratulationsScreen}
          options={{headerShown: false}}
          initialParams={props?.params}
          // initialParams={params}
        />
        <Stack.Screen
          name="QuestionIntro"
          component={QuestionIntro}
          options={{headerShown: false}}
          initialParams={props?.params}
        />
      </Stack.Navigator>
    </NavigationContainer>
  );
};

export default Router;

==> react-native-hotqa-sdk-0.2.7.tgz: package/src/router/index.js <==
import 'react-native-gesture-handler';

import * as React from 'react';
import {NavigationContainer} from '@react-navigation/native';
import {createStackNavigator} from '@react-navigation/stack';
import Icon from 'react-native-vector-icons/FontAwesome';
import Feather from 'react-native-vector-icons/Feather';

//screen
import HomeScreen from '../pages/home';
import StartScreen from '../pages/start';
import CongratulationsScreen from '../components/Congratulations';
import CodeTest from '../components/CodeTest';
import QuestionIntro from '../components/swiper/intro-question';

Icon.loadFont();
Feather.loadFont();
const Stack = createStackNavigator();

const token_fake =
  'EKID eyJhbGciOiJIUzI1NiJ9.eyJzdWIiOiIyMTc3NyIsImlhdCI6MTYzNjQyODYxNiwiZXhwIjoxNjQwMDI4NjE2LCJkZXZpY2VfaWQiOiIwMkQzN0Y5Ri0zQjQ5LTRFQTMtOTczRi0zNEU1M0Q3QTY5RUUiLCJ0eXBlIjoiU1RVREVOVCJ9.ytCryRbmtGIDclSKGZZQVOhaXhxQdDonbz8bSWPbYxA';

const fixLinkTest =
  // 'https://test-dev.ekidpro.com/main/test/free/772/take?code=IO3JZODR33';
  'https://test.ekidpro.com/main/test/free/2347/take?code=1UZTID7KZ7'; //772

const params = {
  nav: 'navigation',
  domain: 'https://api.ekidenglish.edu.vn',
  linkUrl: fixLinkTest,
  token: token_fake,
  student_id: 21777,
  lesson_id: 121,
  isFinish: false,
  isResult: false,
};

const Router = (props) => {
  return (
    <NavigationContainer independent={true}>
      <Stack.Navigator initialRouteName="Home">
        <Stack.Screen
          name="Home"
          component={HomeScreen}
          options={{headerShown: false}}
          initialParams={props?.params}
          // initialParams={params}
        />
        <Stack.Screen
          name="Start"
          component={StartScreen}
          options={{headerShown: false}}
          initialParams={props?.params}
        />
        <Stack.Screen
          name="Congratulations"
          component={CongratulationsScreen}
          options={{headerShown: false}}
          initialParams={props?.params}
          // initialParams={params}
        />
        <Stack.Screen
          name="QuestionIntro"
          component={QuestionIntro}
          options={{headerShown: false}}
          initialParams={props?.params}
        />
      </Stack.Navigator>
    </NavigationContainer>
  );
};

export default Router;
